@@ -1,66 +1,100 @@
 #!/usr/bin/env python
-import re
-import os
-import sys
 import glob
-import platform
-import time
-import shutil
 import logging
+import os
+import platform
+import re
+import shutil
+import sys
 import tempfile
+import time
 
 import requests
 
 from localstack import config
 from localstack.config import KINESIS_PROVIDER
-from localstack.constants import MODULE_MAIN_PATH, INSTALL_DIR_INFRA
-from localstack.utils.common import is_windows
+from localstack.constants import (
+    DEFAULT_SERVICE_PORTS,
+    DYNAMODB_JAR_URL,
+    DYNAMODB_JAR_URL_ALPINE,
+    ELASTICMQ_JAR_URL,
+    ELASTICSEARCH_DEFAULT_VERSION,
+    ELASTICSEARCH_DELETE_MODULES,
+    ELASTICSEARCH_PLUGIN_LIST,
+    ELASTICSEARCH_URLS,
+    INSTALL_DIR_INFRA,
+    KMS_URL_PATTERN,
+    LOCALSTACK_INFRA_PROCESS,
+    LOCALSTACK_MAVEN_VERSION,
+    MODULE_MAIN_PATH,
+    STS_JAR_URL,
+)
 from localstack.utils import bootstrap
-from localstack.constants import (DEFAULT_SERVICE_PORTS, ELASTICMQ_JAR_URL, STS_JAR_URL,
-    ELASTICSEARCH_URLS, ELASTICSEARCH_DEFAULT_VERSION, ELASTICSEARCH_PLUGIN_LIST,
-    ELASTICSEARCH_DELETE_MODULES, DYNAMODB_JAR_URL, DYNAMODB_JAR_URL_ALPINE, LOCALSTACK_MAVEN_VERSION,
-    KMS_URL_PATTERN, LOCALSTACK_INFRA_PROCESS)
-if __name__ == '__main__':
+from localstack.utils.common import is_windows
+
+if __name__ == "__main__":
     bootstrap.bootstrap_installation()
 # noqa: E402
 from localstack.utils.common import (
-    download, parallelize, run, mkdir, load_file, save_file, unzip, untar, rm_rf,
-    chmod_r, is_alpine, in_docker, get_arch, new_tmp_file)
+    chmod_r,
+    download,
+    get_arch,
+    in_docker,
+    is_alpine,
+    load_file,
+    mkdir,
+    new_tmp_file,
+    parallelize,
+    rm_rf,
+    run,
+    save_file,
+    untar,
+    unzip,
+)
 
-INSTALL_DIR_NPM = '%s/node_modules' % MODULE_MAIN_PATH
-INSTALL_DIR_DDB = '%s/dynamodb' % INSTALL_DIR_INFRA
-INSTALL_DIR_KCL = '%s/amazon-kinesis-client' % INSTALL_DIR_INFRA
-INSTALL_DIR_STEPFUNCTIONS = '%s/stepfunctions' % INSTALL_DIR_INFRA
-INSTALL_DIR_KMS = '%s/kms' % INSTALL_DIR_INFRA
-INSTALL_DIR_ELASTICMQ = '%s/elasticmq' % INSTALL_DIR_INFRA
-INSTALL_PATH_LOCALSTACK_FAT_JAR = '%s/localstack-utils-fat.jar' % INSTALL_DIR_INFRA
-INSTALL_PATH_DDB_JAR = os.path.join(INSTALL_DIR_DDB, 'DynamoDBLocal.jar')
-INSTALL_PATH_KCL_JAR = os.path.join(INSTALL_DIR_KCL, 'aws-java-sdk-sts.jar')
-INSTALL_PATH_STEPFUNCTIONS_JAR = os.path.join(INSTALL_DIR_STEPFUNCTIONS, 'StepFunctionsLocal.jar')
-INSTALL_PATH_KMS_BINARY_PATTERN = os.path.join(INSTALL_DIR_KMS, 'local-kms.<arch>.bin')
-INSTALL_PATH_ELASTICMQ_JAR = os.path.join(INSTALL_DIR_ELASTICMQ, 'elasticmq-server.jar')
-INSTALL_PATH_KINESALITE_CLI = os.path.join(INSTALL_DIR_NPM, 'kinesalite', 'cli.js')
-INSTALL_PATH_KINESIS_MOCK = os.path.join(INSTALL_DIR_INFRA, 'kinesis-mock')
-URL_LOCALSTACK_FAT_JAR = ('https://repo1.maven.org/maven2/' +
-    'cloud/localstack/localstack-utils/{v}/localstack-utils-{v}-fat.jar').format(v=LOCALSTACK_MAVEN_VERSION)
-MARKER_FILE_LIGHT_VERSION = '%s/.light-version' % INSTALL_DIR_INFRA
-IMAGE_NAME_SFN_LOCAL = 'amazon/aws-stepfunctions-local'
-ARTIFACTS_REPO = 'https://github.com/localstack/localstack-artifacts'
-SFN_PATCH_CLASS = 'com/amazonaws/stepfunctions/local/runtime/executors/task/LambdaTaskStateExecutor.class'
-SFN_PATCH_CLASS_URL = '%s/raw/master/stepfunctions-local-patch/%s' % (ARTIFACTS_REPO, SFN_PATCH_CLASS)
+INSTALL_DIR_NPM = "%s/node_modules" % MODULE_MAIN_PATH
+INSTALL_DIR_DDB = "%s/dynamodb" % INSTALL_DIR_INFRA
+INSTALL_DIR_KCL = "%s/amazon-kinesis-client" % INSTALL_DIR_INFRA
+INSTALL_DIR_STEPFUNCTIONS = "%s/stepfunctions" % INSTALL_DIR_INFRA
+INSTALL_DIR_KMS = "%s/kms" % INSTALL_DIR_INFRA
+INSTALL_DIR_ELASTICMQ = "%s/elasticmq" % INSTALL_DIR_INFRA
+INSTALL_PATH_LOCALSTACK_FAT_JAR = "%s/localstack-utils-fat.jar" % INSTALL_DIR_INFRA
+INSTALL_PATH_DDB_JAR = os.path.join(INSTALL_DIR_DDB, "DynamoDBLocal.jar")
+INSTALL_PATH_KCL_JAR = os.path.join(INSTALL_DIR_KCL, "aws-java-sdk-sts.jar")
+INSTALL_PATH_STEPFUNCTIONS_JAR = os.path.join(INSTALL_DIR_STEPFUNCTIONS, "StepFunctionsLocal.jar")
+INSTALL_PATH_KMS_BINARY_PATTERN = os.path.join(INSTALL_DIR_KMS, "local-kms.<arch>.bin")
+INSTALL_PATH_ELASTICMQ_JAR = os.path.join(INSTALL_DIR_ELASTICMQ, "elasticmq-server.jar")
+INSTALL_PATH_KINESALITE_CLI = os.path.join(INSTALL_DIR_NPM, "kinesalite", "cli.js")
+INSTALL_PATH_KINESIS_MOCK = os.path.join(INSTALL_DIR_INFRA, "kinesis-mock")
+URL_LOCALSTACK_FAT_JAR = (
+    "https://repo1.maven.org/maven2/"
+    + "cloud/localstack/localstack-utils/{v}/localstack-utils-{v}-fat.jar"
+).format(v=LOCALSTACK_MAVEN_VERSION)
+MARKER_FILE_LIGHT_VERSION = "%s/.light-version" % INSTALL_DIR_INFRA
+IMAGE_NAME_SFN_LOCAL = "amazon/aws-stepfunctions-local"
+ARTIFACTS_REPO = "https://github.com/localstack/localstack-artifacts"
+SFN_PATCH_CLASS = (
+    "com/amazonaws/stepfunctions/local/runtime/executors/task/LambdaTaskStateExecutor.class"
+)
+SFN_PATCH_CLASS_URL = "%s/raw/master/stepfunctions-local-patch/%s" % (
+    ARTIFACTS_REPO,
+    SFN_PATCH_CLASS,
+)
 
 # kinesis-mock version
-KINESIS_MOCK_VERSION = os.environ.get('KINESIS_MOCK_VERSION') or '0.1.0'
-KINESIS_MOCK_RELEASE_URL = 'https://api.github.com/repos/etspaceman/kinesis-mock/releases/tags/' + KINESIS_MOCK_VERSION
+KINESIS_MOCK_VERSION = os.environ.get("KINESIS_MOCK_VERSION") or "0.1.3"
+KINESIS_MOCK_RELEASE_URL = (
+    "https://api.github.com/repos/etspaceman/kinesis-mock/releases/tags/" + KINESIS_MOCK_VERSION
+)
 
-DEBUGPY_MODULE = 'debugpy'
-DEBUGPY_DEPENDENCIES = ['gcc', 'python3-dev', 'musl-dev']
+DEBUGPY_MODULE = "debugpy"
+DEBUGPY_DEPENDENCIES = ["gcc", "python3-dev", "musl-dev"]
 
 # Target version for javac, to ensure compatibility with earlier JREs
-JAVAC_TARGET_VERSION = '1.8'
+JAVAC_TARGET_VERSION = "1.8"
 
 # SQS backend implementation provider - either "moto" or "elasticmq"
-SQS_BACKEND_IMPL = os.environ.get('SQS_PROVIDER') or 'moto'
+SQS_BACKEND_IMPL = os.environ.get("SQS_PROVIDER") or "moto"
 
 # TODO: 2019-10-09: Temporarily overwriting DDB, as we're hitting a SIGSEGV JVM crash with the latest version
 OVERWRITE_DDB_FILES_IN_DOCKER = False
@@ -79,32 +113,32 @@ def get_elasticsearch_install_dir(version=None):
     version = get_elasticsearch_install_version(version)
     if version == ELASTICSEARCH_DEFAULT_VERSION and not os.path.exists(MARKER_FILE_LIGHT_VERSION):
         # install the default version into a subfolder of the code base
-        install_dir = os.path.join(INSTALL_DIR_INFRA, 'elasticsearch')
+        install_dir = os.path.join(INSTALL_DIR_INFRA, "elasticsearch")
     else:
-        install_dir = os.path.join(config.TMP_FOLDER, 'elasticsearch', version)
+        install_dir = os.path.join(config.TMP_FOLDER, "elasticsearch", version)
     return install_dir
 
 
 def install_elasticsearch(version=None):
     version = get_elasticsearch_install_version(version)
     install_dir = get_elasticsearch_install_dir(version)
-    installed_executable = os.path.join(install_dir, 'bin', 'elasticsearch')
+    installed_executable = os.path.join(install_dir, "bin", "elasticsearch")
     if not os.path.exists(installed_executable):
-        log_install_msg('Elasticsearch (%s)' % version)
+        log_install_msg("Elasticsearch (%s)" % version)
         es_url = ELASTICSEARCH_URLS.get(version)
         if not es_url:
             raise Exception('Unable to find download URL for Elasticsearch version "%s"' % version)
         install_dir_parent = os.path.dirname(install_dir)
         mkdir(install_dir_parent)
         # download and extract archive
-        tmp_archive = os.path.join(config.TMP_FOLDER, 'localstack.%s' % os.path.basename(es_url))
+        tmp_archive = os.path.join(config.TMP_FOLDER, "localstack.%s" % os.path.basename(es_url))
         download_and_extract_with_retry(es_url, tmp_archive, install_dir_parent)
-        elasticsearch_dir = glob.glob(os.path.join(install_dir_parent, 'elasticsearch*'))
+        elasticsearch_dir = glob.glob(os.path.join(install_dir_parent, "elasticsearch*"))
         if not elasticsearch_dir:
-            raise Exception('Unable to find Elasticsearch folder in %s' % install_dir_parent)
+            raise Exception("Unable to find Elasticsearch folder in %s" % install_dir_parent)
         shutil.move(elasticsearch_dir[0], install_dir)
 
-        for dir_name in ('data', 'logs', 'modules', 'plugins', 'config/scripts'):
+        for dir_name in ("data", "logs", "modules", "plugins", "config/scripts"):
             dir_path = os.path.join(install_dir, dir_name)
             mkdir(dir_path)
             chmod_r(dir_path, 0o777)
@@ -113,57 +147,59 @@ def install_elasticsearch(version=None):
         for plugin in ELASTICSEARCH_PLUGIN_LIST:
             if is_alpine():
                 # https://github.com/pires/docker-elasticsearch/issues/56
-                os.environ['ES_TMPDIR'] = '/tmp'
-            plugin_binary = os.path.join(install_dir, 'bin', 'elasticsearch-plugin')
-            plugin_dir = os.path.join(install_dir, 'plugins', plugin)
+                os.environ["ES_TMPDIR"] = "/tmp"
+            plugin_binary = os.path.join(install_dir, "bin", "elasticsearch-plugin")
+            plugin_dir = os.path.join(install_dir, "plugins", plugin)
             if not os.path.exists(plugin_dir):
-                LOG.info('Installing Elasticsearch plugin %s' % (plugin))
-                run('%s install -b %s' % (plugin_binary, plugin))
+                LOG.info("Installing Elasticsearch plugin %s" % (plugin))
+                run("%s install -b %s" % (plugin_binary, plugin))
 
     # delete some plugins to free up space
     for plugin in ELASTICSEARCH_DELETE_MODULES:
-        module_dir = os.path.join(install_dir, 'modules', plugin)
+        module_dir = os.path.join(install_dir, "modules", plugin)
         rm_rf(module_dir)
 
     # disable x-pack-ml plugin (not working on Alpine)
-    xpack_dir = os.path.join(install_dir, 'modules', 'x-pack-ml', 'platform')
+    xpack_dir = os.path.join(install_dir, "modules", "x-pack-ml", "platform")
     rm_rf(xpack_dir)
 
     # patch JVM options file - replace hardcoded heap size settings
-    jvm_options_file = os.path.join(install_dir, 'config', 'jvm.options')
+    jvm_options_file = os.path.join(install_dir, "config", "jvm.options")
     if os.path.exists(jvm_options_file):
         jvm_options = load_file(jvm_options_file)
-        jvm_options_replaced = re.sub(r'(^-Xm[sx][a-zA-Z0-9\.]+$)', r'# \1', jvm_options, flags=re.MULTILINE)
+        jvm_options_replaced = re.sub(
+            r"(^-Xm[sx][a-zA-Z0-9\.]+$)", r"# \1", jvm_options, flags=re.MULTILINE
+        )
         if jvm_options != jvm_options_replaced:
             save_file(jvm_options_file, jvm_options_replaced)
 
 
 def install_elasticmq():
-    if SQS_BACKEND_IMPL != 'elasticmq':
+    if SQS_BACKEND_IMPL != "elasticmq":
         return
     # TODO remove this function if we stop using ElasticMQ entirely
     if not os.path.exists(INSTALL_PATH_ELASTICMQ_JAR):
-        log_install_msg('ElasticMQ')
+        log_install_msg("ElasticMQ")
         mkdir(INSTALL_DIR_ELASTICMQ)
         # download archive
-        tmp_archive = os.path.join(config.TMP_FOLDER, 'elasticmq-server.jar')
+        tmp_archive = os.path.join(config.TMP_FOLDER, "elasticmq-server.jar")
         if not os.path.exists(tmp_archive):
             download(ELASTICMQ_JAR_URL, tmp_archive)
         shutil.copy(tmp_archive, INSTALL_DIR_ELASTICMQ)
 
 
 def install_kinesis():
-    if KINESIS_PROVIDER == 'kinesalite':
+    if KINESIS_PROVIDER == "kinesalite":
         return install_kinesalite()
-    elif KINESIS_PROVIDER == 'kinesis-mock':
+    elif KINESIS_PROVIDER == "kinesis-mock":
         return install_kinesis_mock()
     else:
-        raise ValueError('unknown kinesis provider %s' % KINESIS_PROVIDER)
+        raise ValueError("unknown kinesis provider %s" % KINESIS_PROVIDER)
 
 
 def install_kinesalite():
     if not os.path.exists(INSTALL_PATH_KINESALITE_CLI):
-        log_install_msg('Kinesis')
+        log_install_msg("Kinesis")
         run('cd "%s" && npm install' % MODULE_MAIN_PATH)
 
 
@@ -174,54 +210,59 @@ def install_kinesis_mock():
     system = platform.system().lower()
     version = platform.version().lower()
 
-    is_probably_m1 = system == 'darwin' and ('arm64' in version or 'arm32' in version)
+    is_probably_m1 = system == "darwin" and ("arm64" in version or "arm32" in version)
 
-    LOG.debug('getting kinesis-mock for %s %s', system, machine)
-    if ((machine == 'x86_64' or machine == 'amd64') and not is_probably_m1):
-        if system == 'windows':
-            bin_file = 'kinesis-mock-mostly-static.exe'
-        elif system == 'linux':
-            bin_file = 'kinesis-mock-linux-amd64-static'
-        elif system == 'darwin':
-            bin_file = 'kinesis-mock-macos-amd64-dynamic'
+    LOG.debug("getting kinesis-mock for %s %s", system, machine)
+    if (machine == "x86_64" or machine == "amd64") and not is_probably_m1:
+        if system == "windows":
+            bin_file = "kinesis-mock-mostly-static.exe"
+        elif system == "linux":
+            bin_file = "kinesis-mock-linux-amd64-static"
+        elif system == "darwin":
+            bin_file = "kinesis-mock-macos-amd64-dynamic"
         else:
-            bin_file = 'kinesis-mock.jar'
+            bin_file = "kinesis-mock.jar"
     else:
-        bin_file = 'kinesis-mock.jar'
+        bin_file = "kinesis-mock.jar"
 
     bin_file_path = os.path.join(target_dir, bin_file)
     if os.path.exists(bin_file_path):
-        LOG.debug('kinesis-mock found at %s', bin_file_path)
+        LOG.debug("kinesis-mock found at %s", bin_file_path)
         return bin_file_path
 
     response = requests.get(KINESIS_MOCK_RELEASE_URL)
     if not response.ok:
-        raise ValueError('Could not get list of releases from %s: %s' % (KINESIS_MOCK_RELEASE_URL, response.text))
+        raise ValueError(
+            "Could not get list of releases from %s: %s" % (KINESIS_MOCK_RELEASE_URL, response.text)
+        )
 
     github_release = response.json()
     download_url = None
-    for asset in github_release.get('assets', []):
+    for asset in github_release.get("assets", []):
         # find the correct binary in the release
-        if asset['name'] == bin_file:
-            download_url = asset['browser_download_url']
+        if asset["name"] == bin_file:
+            download_url = asset["browser_download_url"]
             break
 
     if download_url is None:
-        raise ValueError('could not find required binary %s in release %s' % (bin_file, KINESIS_MOCK_RELEASE_URL))
+        raise ValueError(
+            "could not find required binary %s in release %s" % (bin_file, KINESIS_MOCK_RELEASE_URL)
+        )
 
     mkdir(target_dir)
-    LOG.info('downloading kinesis-mock binary from %s', download_url)
+    LOG.info("downloading kinesis-mock binary from %s", download_url)
     download(download_url, bin_file_path)
+    chmod_r(bin_file_path, 0o777)
     return bin_file_path
 
 
 def install_local_kms():
     local_arch = get_arch()
-    binary_path = INSTALL_PATH_KMS_BINARY_PATTERN.replace('<arch>', local_arch)
+    binary_path = INSTALL_PATH_KMS_BINARY_PATTERN.replace("<arch>", local_arch)
     if not os.path.exists(binary_path):
-        log_install_msg('KMS')
+        log_install_msg("KMS")
         mkdir(INSTALL_DIR_KMS)
-        kms_url = KMS_URL_PATTERN.replace('<arch>', local_arch)
+        kms_url = KMS_URL_PATTERN.replace("<arch>", local_arch)
         download(kms_url, binary_path)
         chmod_r(binary_path, 0o777)
 
@@ -229,22 +270,32 @@ def install_local_kms():
 def install_stepfunctions_local():
     if not os.path.exists(INSTALL_PATH_STEPFUNCTIONS_JAR):
         # pull the JAR file from the Docker image, which is more up-to-date than the downloadable JAR file
-        log_install_msg('Step Functions')
+        log_install_msg("Step Functions")
         mkdir(INSTALL_DIR_STEPFUNCTIONS)
-        run('{dc} pull {img}'.format(dc=config.DOCKER_CMD, img=IMAGE_NAME_SFN_LOCAL))
-        docker_name = 'tmp-ls-sfn'
-        run(('{dc} run --name={dn} --entrypoint= -d --rm {img} sleep 15').format(
-            dc=config.DOCKER_CMD, dn=docker_name, img=IMAGE_NAME_SFN_LOCAL))
+        run("{dc} pull {img}".format(dc=config.DOCKER_CMD, img=IMAGE_NAME_SFN_LOCAL))
+        docker_name = "tmp-ls-sfn"
+        run(
+            ("{dc} run --name={dn} --entrypoint= -d --rm {img} sleep 15").format(
+                dc=config.DOCKER_CMD, dn=docker_name, img=IMAGE_NAME_SFN_LOCAL
+            )
+        )
         time.sleep(5)
-        run('{dc} cp {dn}:/home/stepfunctionslocal/ {tgt}'.format(dc=config.DOCKER_CMD,
-            dn=docker_name, tgt=INSTALL_DIR_INFRA))
-        run('mv %s/stepfunctionslocal/*.jar %s' % (INSTALL_DIR_INFRA, INSTALL_DIR_STEPFUNCTIONS))
-        rm_rf('%s/stepfunctionslocal' % INSTALL_DIR_INFRA)
+        run(
+            "{dc} cp {dn}:/home/stepfunctionslocal/ {tgt}".format(
+                dc=config.DOCKER_CMD, dn=docker_name, tgt=INSTALL_DIR_INFRA
+            )
+        )
+        run("mv %s/stepfunctionslocal/*.jar %s" % (INSTALL_DIR_INFRA, INSTALL_DIR_STEPFUNCTIONS))
+        rm_rf("%s/stepfunctionslocal" % INSTALL_DIR_INFRA)
     # apply patches
     patch_class_file = os.path.join(INSTALL_DIR_STEPFUNCTIONS, SFN_PATCH_CLASS)
     if not os.path.exists(patch_class_file):
         download(SFN_PATCH_CLASS_URL, patch_class_file)
-        cmd = 'cd "%s"; zip %s %s' % (INSTALL_DIR_STEPFUNCTIONS, INSTALL_PATH_STEPFUNCTIONS_JAR, SFN_PATCH_CLASS)
+        cmd = 'cd "%s"; zip %s %s' % (
+            INSTALL_DIR_STEPFUNCTIONS,
+            INSTALL_PATH_STEPFUNCTIONS_JAR,
+            SFN_PATCH_CLASS,
+        )
         run(cmd)
 
 
@@ -253,9 +304,9 @@ def install_dynamodb_local():
         rm_rf(INSTALL_DIR_DDB)
     is_in_alpine = is_alpine()
     if not os.path.exists(INSTALL_PATH_DDB_JAR):
-        log_install_msg('DynamoDB')
+        log_install_msg("DynamoDB")
         # download and extract archive
-        tmp_archive = os.path.join(tempfile.gettempdir(), 'localstack.ddb.zip')
+        tmp_archive = os.path.join(tempfile.gettempdir(), "localstack.ddb.zip")
         dynamodb_url = DYNAMODB_JAR_URL_ALPINE if is_in_alpine else DYNAMODB_JAR_URL
         download_and_extract_with_retry(dynamodb_url, tmp_archive, INSTALL_DIR_DDB)
 
@@ -270,7 +321,7 @@ def install_dynamodb_local():
         <Root level="WARN"><AppenderRef ref="Console"/></Root>
       </Loggers>
     </Configuration>"""
-    log4j2_file = os.path.join(INSTALL_DIR_DDB, 'log4j2.xml')
+    log4j2_file = os.path.join(INSTALL_DIR_DDB, "log4j2.xml")
     save_file(log4j2_file, log4j2_config)
     run('cd "%s" && zip -u DynamoDBLocal.jar log4j2.xml || true' % INSTALL_DIR_DDB)
 
@@ -279,44 +330,48 @@ def install_amazon_kinesis_client_libs():
     # install KCL/STS JAR files
     if not os.path.exists(INSTALL_PATH_KCL_JAR):
         mkdir(INSTALL_DIR_KCL)
-        tmp_archive = os.path.join(tempfile.gettempdir(), 'aws-java-sdk-sts.jar')
+        tmp_archive = os.path.join(tempfile.gettempdir(), "aws-java-sdk-sts.jar")
         if not os.path.exists(tmp_archive):
             download(STS_JAR_URL, tmp_archive)
         shutil.copy(tmp_archive, INSTALL_DIR_KCL)
     # Compile Java files
     from localstack.utils.kinesis import kclipy_helper
+
     classpath = kclipy_helper.get_kcl_classpath()
 
     if is_windows():
-        classpath = re.sub(r':([^\\])', r';\1', classpath)
-    java_files = '%s/utils/kinesis/java/cloud/localstack/*.java' % MODULE_MAIN_PATH
-    class_files = '%s/utils/kinesis/java/cloud/localstack/*.class' % MODULE_MAIN_PATH
+        classpath = re.sub(r":([^\\])", r";\1", classpath)
+    java_files = "%s/utils/kinesis/java/cloud/localstack/*.java" % MODULE_MAIN_PATH
+    class_files = "%s/utils/kinesis/java/cloud/localstack/*.class" % MODULE_MAIN_PATH
     if not glob.glob(class_files):
-        run('javac -source %s -target %s -cp "%s" %s' % (
-            JAVAC_TARGET_VERSION, JAVAC_TARGET_VERSION, classpath, java_files))
+        run(
+            'javac -source %s -target %s -cp "%s" %s'
+            % (JAVAC_TARGET_VERSION, JAVAC_TARGET_VERSION, classpath, java_files)
+        )
 
 
 def install_lambda_java_libs():
     # install LocalStack "fat" JAR file (contains all dependencies)
     if not os.path.exists(INSTALL_PATH_LOCALSTACK_FAT_JAR):
-        log_install_msg('LocalStack Java libraries', verbatim=True)
+        log_install_msg("LocalStack Java libraries", verbatim=True)
         download(URL_LOCALSTACK_FAT_JAR, INSTALL_PATH_LOCALSTACK_FAT_JAR)
 
 
 def install_cloudformation_libs():
     from localstack.services.cloudformation import deployment_utils
+
     # trigger download of CF module file
     deployment_utils.get_cfn_response_mod_file()
 
 
 def install_component(name):
     installers = {
-        'cloudformation': install_cloudformation_libs,
-        'dynamodb': install_dynamodb_local,
-        'kinesis': install_kinesis,
-        'kms': install_local_kms,
-        'sqs': install_elasticmq,
-        'stepfunctions': install_stepfunctions_local,
+        "cloudformation": install_cloudformation_libs,
+        "dynamodb": install_dynamodb_local,
+        "kinesis": install_kinesis,
+        "kms": install_local_kms,
+        "sqs": install_elasticmq,
+        "stepfunctions": install_stepfunctions_local,
     }
     installer = installers.get(name)
     if installer:
@@ -330,7 +385,7 @@ def install_components(names):
 
 def install_all_components():
     # load plugins
-    os.environ[LOCALSTACK_INFRA_PROCESS] = '1'
+    os.environ[LOCALSTACK_INFRA_PROCESS] = "1"
     bootstrap.load_plugins()
     # install all components
     install_components(DEFAULT_SERVICE_PORTS.keys())
@@ -339,20 +394,27 @@ def install_all_components():
 def install_debugpy_and_dependencies():
     try:
         import debugpy
+
         assert debugpy
+        logging.debug("Debugpy module already Installed")
     except ModuleNotFoundError:
-        run('apk fetch %s --output %s' % (' '.join(DEBUGPY_DEPENDENCIES), config.TMP_FOLDER))
-        run('apk add %s --cache-dir %s' % (' '.join(DEBUGPY_DEPENDENCIES), config.TMP_FOLDER))
-        run('pip install %s' % DEBUGPY_MODULE)
+        logging.debug("Installing Debugpy module")
+        import pip
+
+        if hasattr(pip, "main"):
+            pip.main(["install", DEBUGPY_MODULE])
+        else:
+            pip._internal.main(["install", DEBUGPY_MODULE])
 
 
 # -----------------
 # HELPER FUNCTIONS
 # -----------------
 
+
 def log_install_msg(component, verbatim=False):
-    component = component if verbatim else 'local %s server' % component
-    LOG.info('Downloading and installing %s. This may take some time.' % component)
+    component = component if verbatim else "local %s server" % component
+    LOG.info("Downloading and installing %s. This may take some time." % component)
 
 
 def download_and_extract(archive_url, target_dir, retries=0, sleep=3, tmp_archive=None):
@@ -361,7 +423,7 @@ def download_and_extract(archive_url, target_dir, retries=0, sleep=3, tmp_archiv
     tmp_archive = tmp_archive or new_tmp_file()
     if not os.path.exists(tmp_archive):
         # create temporary placeholder file, to avoid duplicate parallel downloads
-        save_file(tmp_archive, '')
+        save_file(tmp_archive, "")
         for i in range(retries + 1):
             try:
                 download(archive_url, tmp_archive)
@@ -370,12 +432,12 @@ def download_and_extract(archive_url, target_dir, retries=0, sleep=3, tmp_archiv
                 time.sleep(sleep)
 
     _, ext = os.path.splitext(tmp_archive)
-    if ext == '.zip':
+    if ext == ".zip":
         unzip(tmp_archive, target_dir)
-    elif ext == '.gz' or ext == '.bz2':
+    elif ext == ".gz" or ext == ".bz2":
         untar(tmp_archive, target_dir)
     else:
-        raise Exception('Unsupported archive format: %s' % ext)
+        raise Exception("Unsupported archive format: %s" % ext)
 
 
 def download_and_extract_with_retry(archive_url, tmp_archive, target_dir):
@@ -383,24 +445,24 @@ def download_and_extract_with_retry(archive_url, tmp_archive, target_dir):
         download_and_extract(archive_url, target_dir, tmp_archive=tmp_archive)
     except Exception as e:
         # try deleting and re-downloading the zip file
-        LOG.info('Unable to extract file, re-downloading ZIP archive %s: %s' % (tmp_archive, e))
+        LOG.info("Unable to extract file, re-downloading ZIP archive %s: %s" % (tmp_archive, e))
         rm_rf(tmp_archive)
         download_and_extract(archive_url, target_dir, tmp_archive=tmp_archive)
 
 
 def main():
     if len(sys.argv) > 1:
-        os.environ['LOCALSTACK_API_KEY'] = os.environ.get('LOCALSTACK_API_KEY') or 'test'
-        if sys.argv[1] == 'libs':
-            print('Initializing installation.')
+        os.environ["LOCALSTACK_API_KEY"] = os.environ.get("LOCALSTACK_API_KEY") or "test"
+        if sys.argv[1] == "libs":
+            print("Initializing installation.")
             logging.basicConfig(level=logging.INFO)
-            logging.getLogger('requests').setLevel(logging.WARNING)
+            logging.getLogger("requests").setLevel(logging.WARNING)
             install_all_components()
-        if sys.argv[1] in ('libs', 'testlibs'):
+        if sys.argv[1] in ("libs", "testlibs"):
             # Install additional libraries for testing
             install_amazon_kinesis_client_libs()
-        print('Done.')
+        print("Done.")
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
