@@ -1,13 +1,14 @@
 import json
-import time
 import logging
+import time
 import traceback
 from concurrent.futures import ThreadPoolExecutor
 
 import requests
+
 from localstack import config
-from localstack.utils.common import clone
 from localstack.utils.bootstrap import canonicalize_api_names
+from localstack.utils.common import clone
 
 # set up logger
 LOG = logging.getLogger(__name__)
@@ -23,8 +24,8 @@ STATUSES = {}
 # PLUGIN UTILITIES
 # -----------------
 
-class Plugin(object):
 
+class Plugin(object):
     def __init__(self, name, start, check=None, listener=None, priority=0, active=False):
         self.plugin_name = name
         self.start_function = start
@@ -34,11 +35,9 @@ class Plugin(object):
         self.default_active = active
 
     def start(self, asynchronous):
-        kwargs = {
-            'asynchronous': asynchronous
-        }
+        kwargs = {"asynchronous": asynchronous}
         if self.listener:
-            kwargs['update_listener'] = self.listener
+            kwargs["update_listener"] = self.listener
         return self.start_function(**kwargs)
 
     def check(self, expect_shutdown=False, print_error=False):
@@ -69,18 +68,19 @@ def register_plugin(plugin):
 # HEALTH CHECK API METHODS
 # -------------------------
 
+
 def get_services_health(reload=False):
     if reload:
         reload_services_health()
     result = clone(dict(STATUSES))
-    result.get('services', {}).pop('edge', None)
+    result.get("services", {}).pop("edge", None)
     return result
 
 
 def set_services_health(data):
-    status = STATUSES['services'] = STATUSES.get('services', {})
+    status = STATUSES["services"] = STATUSES.get("services", {})
     for key, value in dict(data).items():
-        parent, _, child = key.partition(':')
+        parent, _, child = key.partition(":")
         if child:
             STATUSES[parent] = STATUSES.get(parent, {})
             STATUSES[parent][child] = value
@@ -93,6 +93,7 @@ def set_services_health(data):
 # INFRASTRUCTURE HEALTH CHECKS
 # -----------------------------
 
+
 def check_infra(retries=10, expect_shutdown=False, apis=None, additional_checks=[]):
     try:
         apis = apis or canonicalize_api_names()
@@ -101,16 +102,26 @@ def check_infra(retries=10, expect_shutdown=False, apis=None, additional_checks=
         # loop through plugins and check service status
         for name, plugin in SERVICE_PLUGINS.items():
             if name in apis:
-                check_service_health(api=name, print_error=print_error, expect_shutdown=expect_shutdown)
+                check_service_health(
+                    api=name, print_error=print_error, expect_shutdown=expect_shutdown
+                )
 
         for additional in additional_checks:
             additional(expect_shutdown=expect_shutdown)
     except Exception as e:
         if retries <= 0:
-            LOG.error('Error checking state of local environment (after some retries): %s' % traceback.format_exc())
+            LOG.error(
+                "Error checking state of local environment (after some retries): %s"
+                % traceback.format_exc()
+            )
             raise e
         time.sleep(3)
-        check_infra(retries - 1, expect_shutdown=expect_shutdown, apis=apis, additional_checks=additional_checks)
+        check_infra(
+            retries - 1,
+            expect_shutdown=expect_shutdown,
+            apis=apis,
+            additional_checks=additional_checks,
+        )
 
 
 def wait_for_infra_shutdown(apis=None):
@@ -120,7 +131,7 @@ def wait_for_infra_shutdown(apis=None):
 
     def check(name):
         check_service_health(api=name, expect_shutdown=True)
-        LOG.debug('[shutdown] api %s has shut down', name)
+        LOG.debug("[shutdown] api %s has shut down", name)
 
     # no special significance to 10 workers, seems like a reasonable number given the number of services we have
     with ThreadPoolExecutor(max_workers=10) as executor:
@@ -131,7 +142,7 @@ def check_service_health(api, print_error=False, expect_shutdown=False):
     try:
         plugin = SERVICE_PLUGINS.get(api)
         plugin.check(expect_shutdown=expect_shutdown, print_error=print_error)
-        record_service_health(api, 'running')
+        record_service_health(api, "running")
     except Exception as e:
         if not expect_shutdown:
             LOG.warning('Service "%s" not yet available, retrying...' % api)
@@ -146,10 +157,8 @@ def reload_services_health():
 
 def record_service_health(api, status):
     # TODO: consider making in-memory calls here, to optimize performance
-    data = {
-        api: status
-    }
-    health_url = '%s/health' % config.get_edge_url()
+    data = {api: status}
+    health_url = "%s/health" % config.get_edge_url()
     try:
         requests.put(health_url, data=json.dumps(data), verify=False)
     except Exception:
