@@ -1,42 +1,44 @@
-import os
 import json
+import os
 import time
+
 from six.moves import queue
+
 from localstack import config
 from localstack.constants import API_ENDPOINT
-from localstack.utils.common import (
-    JsonObject, timestamp, short_uid, save_file, FuncThread, get_or_create_file)
+from localstack.utils.common import FuncThread, JsonObject, get_or_create_file
 from localstack.utils.common import safe_requests as requests
+from localstack.utils.common import save_file, short_uid, timestamp
 
 PROCESS_ID = short_uid()
 MACHINE_ID = None
 
 # event type constants
-EVENT_START_INFRA = 'inf.up'
-EVENT_STOP_INFRA = 'inf.dn'
-EVENT_KINESIS_CREATE_STREAM = 'kns.cs'
-EVENT_KINESIS_DELETE_STREAM = 'kns.ds'
-EVENT_LAMBDA_CREATE_FUNC = 'lmb.cf'
-EVENT_LAMBDA_DELETE_FUNC = 'lmb.df'
-EVENT_LAMBDA_INVOKE_FUNC = 'lmb.if'
-EVENT_SQS_CREATE_QUEUE = 'sqs.cq'
-EVENT_SQS_DELETE_QUEUE = 'sqs.dq'
-EVENT_SNS_CREATE_TOPIC = 'sns.ct'
-EVENT_SNS_DELETE_TOPIC = 'sns.dt'
-EVENT_S3_CREATE_BUCKET = 's3.cb'
-EVENT_S3_DELETE_BUCKET = 's3.db'
-EVENT_STEPFUNCTIONS_CREATE_SM = 'stf.cm'
-EVENT_STEPFUNCTIONS_DELETE_SM = 'stf.dm'
-EVENT_APIGW_CREATE_API = 'agw.ca'
-EVENT_APIGW_DELETE_API = 'agw.da'
-EVENT_DYNAMODB_CREATE_TABLE = 'ddb.ct'
-EVENT_DYNAMODB_DELETE_TABLE = 'ddb.dt'
-EVENT_DYNAMODB_CREATE_STREAM = 'ddb.cs'
-EVENT_CLOUDFORMATION_CREATE_STACK = 'clf.cs'
-EVENT_ES_CREATE_DOMAIN = 'es.cd'
-EVENT_ES_DELETE_DOMAIN = 'es.dd'
-EVENT_FIREHOSE_CREATE_STREAM = 'fho.cs'
-EVENT_FIREHOSE_DELETE_STREAM = 'fho.ds'
+EVENT_START_INFRA = "inf.up"
+EVENT_STOP_INFRA = "inf.dn"
+EVENT_KINESIS_CREATE_STREAM = "kns.cs"
+EVENT_KINESIS_DELETE_STREAM = "kns.ds"
+EVENT_LAMBDA_CREATE_FUNC = "lmb.cf"
+EVENT_LAMBDA_DELETE_FUNC = "lmb.df"
+EVENT_LAMBDA_INVOKE_FUNC = "lmb.if"
+EVENT_SQS_CREATE_QUEUE = "sqs.cq"
+EVENT_SQS_DELETE_QUEUE = "sqs.dq"
+EVENT_SNS_CREATE_TOPIC = "sns.ct"
+EVENT_SNS_DELETE_TOPIC = "sns.dt"
+EVENT_S3_CREATE_BUCKET = "s3.cb"
+EVENT_S3_DELETE_BUCKET = "s3.db"
+EVENT_STEPFUNCTIONS_CREATE_SM = "stf.cm"
+EVENT_STEPFUNCTIONS_DELETE_SM = "stf.dm"
+EVENT_APIGW_CREATE_API = "agw.ca"
+EVENT_APIGW_DELETE_API = "agw.da"
+EVENT_DYNAMODB_CREATE_TABLE = "ddb.ct"
+EVENT_DYNAMODB_DELETE_TABLE = "ddb.dt"
+EVENT_DYNAMODB_CREATE_STREAM = "ddb.cs"
+EVENT_CLOUDFORMATION_CREATE_STACK = "clf.cs"
+EVENT_ES_CREATE_DOMAIN = "es.cd"
+EVENT_ES_DELETE_DOMAIN = "es.dd"
+EVENT_FIREHOSE_CREATE_STREAM = "fho.cs"
+EVENT_FIREHOSE_DELETE_STREAM = "fho.ds"
 
 # sender thread and queue
 SENDER_THREAD = None
@@ -44,14 +46,13 @@ EVENT_QUEUE = queue.Queue()
 
 
 class AnalyticsEvent(JsonObject):
-
     def __init__(self, **kwargs):
-        self.t = kwargs.get('timestamp') or kwargs.get('t') or timestamp()
-        self.m_id = kwargs.get('machine_id') or kwargs.get('m_id') or get_machine_id()
-        self.p_id = kwargs.get('process_id') or kwargs.get('p_id') or get_process_id()
-        self.p = kwargs.get('payload') if kwargs.get('payload') is not None else kwargs.get('p')
-        self.k = kwargs.get('api_key') or kwargs.get('k') or read_api_key_safe()
-        self.e_t = kwargs.get('event_type') or kwargs.get('e_t')
+        self.t = kwargs.get("timestamp") or kwargs.get("t") or timestamp()
+        self.m_id = kwargs.get("machine_id") or kwargs.get("m_id") or get_machine_id()
+        self.p_id = kwargs.get("process_id") or kwargs.get("p_id") or get_process_id()
+        self.p = kwargs.get("payload") if kwargs.get("payload") is not None else kwargs.get("p")
+        self.k = kwargs.get("api_key") or kwargs.get("k") or read_api_key_safe()
+        self.e_t = kwargs.get("event_type") or kwargs.get("e_t")
 
     def timestamp(self):
         return self.t
@@ -75,6 +76,7 @@ class AnalyticsEvent(JsonObject):
 def read_api_key_safe():
     try:
         from localstack_ext.bootstrap.licensing import read_api_key
+
         return read_api_key()
     except Exception:
         return None
@@ -90,7 +92,7 @@ def get_config_file_homedir():
 
 
 def get_config_file_tempdir():
-    return _get_config_file(os.path.join(config.TMP_FOLDER, '.localstack'))
+    return _get_config_file(os.path.join(config.TMP_FOLDER, ".localstack"))
 
 
 def get_machine_id():
@@ -105,9 +107,11 @@ def get_machine_id():
     config_file_home = get_config_file_homedir()
     for config_file in (config_file_home, config_file_tmp):
         if config_file:
-            local_configs = configs_map[config_file] = config.load_config_file(config_file=config_file)
-            if 'machine_id' in local_configs:
-                MACHINE_ID = local_configs['machine_id']
+            local_configs = configs_map[config_file] = config.load_config_file(
+                config_file=config_file
+            )
+            if "machine_id" in local_configs:
+                MACHINE_ID = local_configs["machine_id"]
                 break
 
     # if we can neither find NOR create the config files, fall back to process id
@@ -120,7 +124,7 @@ def get_machine_id():
 
     # update MACHINE_ID in all config files
     for config_file, configs in configs_map.items():
-        configs['machine_id'] = MACHINE_ID
+        configs["machine_id"] = MACHINE_ID
         save_file(config_file, json.dumps(configs))
 
     return MACHINE_ID
@@ -135,7 +139,7 @@ def poll_and_send_messages(params):
         try:
             event = EVENT_QUEUE.get(block=True, timeout=None)
             event = event.to_dict()
-            endpoint = '%s/events' % API_ENDPOINT.rstrip('/')
+            endpoint = "%s/events" % API_ENDPOINT.rstrip("/")
             requests.post(endpoint, json=event)
         except Exception:
             # silently fail, make collection of usage data as non-intrusive as possible
@@ -143,15 +147,15 @@ def poll_and_send_messages(params):
 
 
 def is_travis():
-    return os.environ.get('TRAVIS', '').lower() in ['true', '1']
+    return os.environ.get("TRAVIS", "").lower() in ["true", "1"]
 
 
 def get_hash(name):
     if not name:
-        return '0'
+        return "0"
     max_hash = 10000000000
     hashed = hash(name) % max_hash
-    hashed = hex(hashed).replace('0x', '')
+    hashed = hex(hashed).replace("0x", "")
     return hashed
 
 
@@ -166,14 +170,17 @@ def fire_event(event_type, payload=None):
     if not api_key:
         # only store events if API key has been specified
         return
-    from localstack.utils.testutil import is_local_test_mode  # leave here to avoid circular dependency
+    from localstack.utils.testutil import (  # leave here to avoid circular dependency
+        is_local_test_mode,
+    )
+
     if payload is None:
         payload = {}
     if isinstance(payload, dict):
         if is_travis():
-            payload['travis'] = True
+            payload["travis"] = True
         if is_local_test_mode():
-            payload['int'] = True
+            payload["int"] = True
 
     event = AnalyticsEvent(event_type=event_type, payload=payload, api_key=api_key)
     EVENT_QUEUE.put_nowait(event)
