@@ -1,7 +1,9 @@
-import time
 import json
-import six
+import time
 from datetime import datetime
+
+import six
+
 from localstack.utils.common import timestamp_millis
 
 if six.PY3:
@@ -21,7 +23,7 @@ class Component(object):
         return self.__str__()
 
     def __str__(self):
-        return '<%s:%s>' % (self.__class__.__name__, self.id)
+        return "<%s:%s>" % (self.__class__.__name__, self.id)
 
 
 class KinesisStream(Component):
@@ -29,20 +31,20 @@ class KinesisStream(Component):
         super(KinesisStream, self).__init__(id)
         params = params or {}
         self.shards = []
-        self.stream_name = params.get('name', self.name())
-        self.num_shards = params.get('shards', num_shards)
+        self.stream_name = params.get("name", self.name())
+        self.num_shards = params.get("shards", num_shards)
         self.conn = connection
         self.stream_info = params
 
     def name(self):
-        return self.id.split(':stream/')[-1]
+        return self.id.split(":stream/")[-1]
 
     def connect(self, connection):
         self.conn = connection
 
     def describe(self):
         r = self.conn.describe_stream(StreamName=self.stream_name)
-        return r.get('StreamDescription')
+        return r.get("StreamDescription")
 
     def create(self, raise_on_error=False):
         try:
@@ -54,26 +56,26 @@ class KinesisStream(Component):
 
     def get_status(self):
         description = self.describe()
-        return description.get('StreamStatus')
+        return description.get("StreamStatus")
 
     def put(self, data, key):
         if not isinstance(data, str):
             data = json.dumps(data)
         return self.conn.put_record(StreamName=self.stream_name, Data=data, PartitionKey=key)
 
-    def read(self, amount=-1, shard='shardId-000000000001'):
+    def read(self, amount=-1, shard="shardId-000000000001"):
         if not self.conn:
-            raise Exception('Please create the Kinesis connection first.')
-        s_iterator = self.conn.get_shard_iterator(self.stream_name, shard, 'TRIM_HORIZON')
-        record = self.conn.get_records(s_iterator['ShardIterator'])
+            raise Exception("Please create the Kinesis connection first.")
+        s_iterator = self.conn.get_shard_iterator(self.stream_name, shard, "TRIM_HORIZON")
+        record = self.conn.get_records(s_iterator["ShardIterator"])
         while True:
             try:
-                if record['NextShardIterator'] is None:
+                if record["NextShardIterator"] is None:
                     break
                 else:
-                    next_entry = self.conn.get_records(record['NextShardIterator'])
-                    if len(next_entry['Records']):
-                        print(next_entry['Records'][0]['Data'])
+                    next_entry = self.conn.get_records(record["NextShardIterator"])
+                    if len(next_entry["Records"]):
+                        print(next_entry["Records"][0]["Data"])
                     record = next_entry
             except Exception as e:
                 print('Error reading from Kinesis stream "%s": %s' % (self.stream_name, e))
@@ -84,7 +86,7 @@ class KinesisStream(Component):
         for i in range(0, GET_STATUS_RETRIES):
             try:
                 status = self.get_status()
-                if status == 'ACTIVE':
+                if status == "ACTIVE":
                     return
             except Exception:
                 # swallowing this exception should be ok, as we are in a retry loop
@@ -98,19 +100,19 @@ class KinesisStream(Component):
 
 
 class KinesisShard(Component):
-    MAX_KEY = '340282366920938463463374607431768211455'
+    MAX_KEY = "340282366920938463463374607431768211455"
 
     def __init__(self, id):
         super(KinesisShard, self).__init__(id)
         self.stream = None
-        self.start_key = '0'
+        self.start_key = "0"
         self.end_key = KinesisShard.MAX_KEY  # 128 times '1' binary as decimal
         self.child_shards = []
 
-    def print_tree(self, indent=''):
-        print('%s%s' % (indent, self))
+    def print_tree(self, indent=""):
+        print("%s%s" % (indent, self))
         for c in self.child_shards:
-            c.print_tree(indent=indent + '   ')
+            c.print_tree(indent=indent + "   ")
 
     def length(self):
         return long(self.end_key) - long(self.start_key)
@@ -119,9 +121,13 @@ class KinesisShard(Component):
         return 100.0 * self.length() / float(KinesisShard.MAX_KEY)
 
     def __str__(self):
-        return ('Shard(%s, length=%s, percent=%s, start=%s, end=%s)' %
-                (self.id, self.length(), self.percent(), self.start_key,
-                    self.end_key))
+        return "Shard(%s, length=%s, percent=%s, start=%s, end=%s)" % (
+            self.id,
+            self.length(),
+            self.percent(),
+            self.start_key,
+            self.end_key,
+        )
 
     @staticmethod
     def sort(shards):
@@ -134,6 +140,7 @@ class KinesisShard(Component):
                 return 1
             else:
                 return 0
+
         return sorted(shards, cmp=compare)
 
     @staticmethod
@@ -153,16 +160,16 @@ class FirehoseStream(KinesisStream):
         self.destinations = []
 
     def name(self):
-        return self.id.split(':deliverystream/')[-1]
+        return self.id.split(":deliverystream/")[-1]
 
 
-class CodeSigningConfig():
+class CodeSigningConfig:
     def __init__(self, arn, id, signing_profile_version_arns):
         self.arn = arn
         self.id = id
         self.signing_profile_version_arns = signing_profile_version_arns
-        self.description = ''
-        self.untrusted_artifact_on_deployment = 'Warn'
+        self.description = ""
+        self.untrusted_artifact_on_deployment = "Warn"
         self.last_modified = None
 
 
@@ -191,61 +198,61 @@ class LambdaFunction(Component):
         self.on_failed_invocation = None
         self.max_retry_attempts = None
         self.max_event_age = None
-        self.description = ''
+        self.description = ""
         self.code_signing_config_arn = None
         self.package_type = None
         self.image_config = {}
 
     def set_dead_letter_config(self, data):
-        config = data.get('DeadLetterConfig')
+        config = data.get("DeadLetterConfig")
         if not config:
             return
         self.dead_letter_config = config
-        target_arn = config.get('TargetArn') or ''
-        if ':sqs:' not in target_arn and ':sns:' not in target_arn:
-            raise Exception('Dead letter queue ARN "%s" requires a valid SQS queue or SNS topic' % target_arn)
+        target_arn = config.get("TargetArn") or ""
+        if ":sqs:" not in target_arn and ":sns:" not in target_arn:
+            raise Exception(
+                'Dead letter queue ARN "%s" requires a valid SQS queue or SNS topic' % target_arn
+            )
 
     def get_function_event_invoke_config(self):
         response = {}
 
         if self.max_retry_attempts:
-            response.update({'MaximumRetryAttempts': self.max_retry_attempts})
+            response.update({"MaximumRetryAttempts": self.max_retry_attempts})
 
         if self.max_event_age:
-            response.update({'MaximumEventAgeInSeconds': self.max_event_age})
+            response.update({"MaximumEventAgeInSeconds": self.max_event_age})
 
         if self.on_successful_invocation or self.on_failed_invocation:
-            response.update({'DestinationConfig': {}})
+            response.update({"DestinationConfig": {}})
             if self.on_successful_invocation:
-                response['DestinationConfig'].update({
-                    'OnSuccess': {
-                        'Destination': self.on_successful_invocation
-                    }
-                })
+                response["DestinationConfig"].update(
+                    {"OnSuccess": {"Destination": self.on_successful_invocation}}
+                )
             if self.on_failed_invocation:
-                response['DestinationConfig'].update({
-                    'OnFailure': {
-                        'Destination': self.on_failed_invocation
-                    }
-                })
+                response["DestinationConfig"].update(
+                    {"OnFailure": {"Destination": self.on_failed_invocation}}
+                )
         if not response:
             return None
-        response.update({
-            'LastModified': timestamp_millis(self.last_modified),
-            'FunctionArn': str(self.id),
-        })
+        response.update(
+            {
+                "LastModified": timestamp_millis(self.last_modified),
+                "FunctionArn": str(self.id),
+            }
+        )
         return response
 
     def clear_function_event_invoke_config(self):
-        if hasattr(self, 'dead_letter_config'):
+        if hasattr(self, "dead_letter_config"):
             self.dead_letter_config = None
-        if hasattr(self, 'on_successful_invocation'):
+        if hasattr(self, "on_successful_invocation"):
             self.on_successful_invocation = None
-        if hasattr(self, 'on_failed_invocation'):
+        if hasattr(self, "on_failed_invocation"):
             self.on_failed_invocation = None
-        if hasattr(self, 'max_retry_attempts'):
+        if hasattr(self, "max_retry_attempts"):
             self.max_retry_attempts = None
-        if hasattr(self, 'max_event_age'):
+        if hasattr(self, "max_event_age"):
             self.max_event_age = None
 
     def put_function_event_invoke_config(self, data):
@@ -253,29 +260,29 @@ class LambdaFunction(Component):
             return
 
         updated = False
-        if 'DestinationConfig' in data:
-            if 'OnFailure' in data['DestinationConfig']:
-                dlq_arn = data['DestinationConfig']['OnFailure']['Destination']
+        if "DestinationConfig" in data:
+            if "OnFailure" in data["DestinationConfig"]:
+                dlq_arn = data["DestinationConfig"]["OnFailure"]["Destination"]
                 self.on_failed_invocation = dlq_arn
                 updated = True
 
-            if 'OnSuccess' in data['DestinationConfig']:
-                sq_arn = data['DestinationConfig']['OnSuccess']['Destination']
+            if "OnSuccess" in data["DestinationConfig"]:
+                sq_arn = data["DestinationConfig"]["OnSuccess"]["Destination"]
                 self.on_successful_invocation = sq_arn
                 updated = True
 
-        if 'MaximumRetryAttempts' in data:
+        if "MaximumRetryAttempts" in data:
             try:
-                max_retry_attempts = int(data['MaximumRetryAttempts'])
+                max_retry_attempts = int(data["MaximumRetryAttempts"])
             except Exception:
                 max_retry_attempts = 3
 
             self.max_retry_attempts = max_retry_attempts
             updated = True
 
-        if 'MaximumEventAgeInSeconds' in data:
+        if "MaximumEventAgeInSeconds" in data:
             try:
-                max_event_age = int(data['MaximumEventAgeInSeconds'])
+                max_event_age = int(data["MaximumEventAgeInSeconds"])
             except Exception:
                 max_event_age = 3600
 
@@ -294,33 +301,36 @@ class LambdaFunction(Component):
         return self.versions.get(version)
 
     def max_version(self):
-        versions = [int(key) for key in self.versions.keys() if key != '$LATEST']
+        versions = [int(key) for key in self.versions.keys() if key != "$LATEST"]
         return versions and max(versions) or 0
 
     def name(self):
         # Example ARN: arn:aws:lambda:aws-region:acct-id:function:helloworld:1
-        return self.id.split(':')[6]
+        return self.id.split(":")[6]
 
     def region(self):
-        return self.id.split(':')[3]
+        return self.id.split(":")[3]
 
     def arn(self):
         return self.id
 
     def function(self, qualifier=None):
-        return self.versions.get(self.get_qualifier_version(qualifier)).get('Function')
+        return self.versions.get(self.get_qualifier_version(qualifier)).get("Function")
 
     def get_qualifier_version(self, qualifier=None):
         if not qualifier:
-            qualifier = '$LATEST'
-        return qualifier if qualifier in self.versions else \
-            self.aliases.get(qualifier).get('FunctionVersion')
+            qualifier = "$LATEST"
+        return (
+            qualifier
+            if qualifier in self.versions
+            else self.aliases.get(qualifier).get("FunctionVersion")
+        )
 
     def qualifier_exists(self, qualifier):
         return qualifier in self.aliases or qualifier in self.versions
 
     def __str__(self):
-        return '<%s:%s>' % (self.__class__.__name__, self.name())
+        return "<%s:%s>" % (self.__class__.__name__, self.name())
 
 
 class DynamoDB(Component):
@@ -330,7 +340,7 @@ class DynamoDB(Component):
         self.bytes = -1
 
     def name(self):
-        return self.id.split(':table/')[-1]
+        return self.id.split(":table/")[-1]
 
 
 class DynamoDBStream(Component):
@@ -348,9 +358,7 @@ class DynamoDBItem(Component):
     def __eq__(self, other):
         if not isinstance(other, DynamoDBItem):
             return False
-        return (other.table == self.table and
-            other.id == self.id and
-            other.keys == self.keys)
+        return other.table == self.table and other.id == self.id and other.keys == self.keys
 
     def __hash__(self):
         return hash(self.table) + hash(self.id) + hash(self.keys)
@@ -363,7 +371,7 @@ class ElasticSearch(Component):
         self.endpoint = None
 
     def name(self):
-        return self.id.split(':domain/')[-1]
+        return self.id.split(":domain/")[-1]
 
 
 class SqsQueue(Component):
@@ -371,7 +379,7 @@ class SqsQueue(Component):
         super(SqsQueue, self).__init__(id)
 
     def name(self):
-        return self.id.split(':')[-1]
+        return self.id.split(":")[-1]
 
 
 class S3Bucket(Component):
@@ -380,7 +388,7 @@ class S3Bucket(Component):
         self.notifications = []
 
     def name(self):
-        return self.id.split('arn:aws:s3:::')[-1]
+        return self.id.split("arn:aws:s3:::")[-1]
 
 
 class S3Notification(Component):
@@ -404,19 +412,19 @@ class EventSource(Component):
         if obj in pool:
             return pool[obj]
         inst = None
-        if obj.startswith('arn:aws:kinesis:'):
+        if obj.startswith("arn:aws:kinesis:"):
             inst = KinesisStream(obj)
-        elif obj.startswith('arn:aws:lambda:'):
+        elif obj.startswith("arn:aws:lambda:"):
             inst = LambdaFunction(obj)
-        elif obj.startswith('arn:aws:dynamodb:'):
-            if '/stream/' in obj:
-                table_id = obj.split('/stream/')[0]
+        elif obj.startswith("arn:aws:dynamodb:"):
+            if "/stream/" in obj:
+                table_id = obj.split("/stream/")[0]
                 table = DynamoDB(table_id)
                 inst = DynamoDBStream(obj)
                 inst.table = table
             else:
                 inst = DynamoDB(obj)
-        elif obj.startswith('arn:aws:sqs:'):
+        elif obj.startswith("arn:aws:sqs:"):
             inst = SqsQueue(obj)
         elif type:
             for o in EventSource.filter_type(pool, type):
