@@ -1,22 +1,24 @@
-import os
-import re
-import sys
-import json
-import time
-import select
 import inspect
+import json
 import logging
+import os
 import pkgutil
-import warnings
-import threading
-import traceback
-import subprocess
-import six
+import re
+import select
 import shutil
-import pip as pip_mod
-from datetime import datetime
+import subprocess
+import sys
+import threading
+import time
+import traceback
+import warnings
 from concurrent.futures._base import Future
-from localstack import constants, config
+from datetime import datetime
+
+import pip as pip_mod
+import six
+
+from localstack import config, constants
 from localstack.utils.analytics.profiler import log_duration
 
 # set up logger
@@ -27,36 +29,45 @@ PLUGINS_LOADED = {}
 
 # predefined list of plugin modules, to speed up the plugin loading at startup
 # note: make sure to load localstack_ext before localstack
-PLUGIN_MODULES = ['localstack_ext', 'localstack']
+PLUGIN_MODULES = ["localstack_ext", "localstack"]
 
 # marker for extended/ignored libs in requirements.txt
-IGNORED_LIB_MARKER = '#extended-lib'
-BASIC_LIB_MARKER = '#basic-lib'
+IGNORED_LIB_MARKER = "#extended-lib"
+BASIC_LIB_MARKER = "#basic-lib"
 
 # whether or not to manually fix permissions on /var/run/docker.sock (currently disabled)
 DO_CHMOD_DOCKER_SOCK = False
 
 # log format strings
-LOG_FORMAT = '%(asctime)s:%(levelname)s:%(name)s: %(message)s'
-LOG_DATE_FORMAT = '%Y-%m-%dT%H:%M:%S'
+LOG_FORMAT = "%(asctime)s:%(levelname)s:%(name)s: %(message)s"
+LOG_DATE_FORMAT = "%Y-%m-%dT%H:%M:%S"
 
 # plugin scopes
-PLUGIN_SCOPE_SERVICES = 'services'
-PLUGIN_SCOPE_COMMANDS = 'commands'
+PLUGIN_SCOPE_SERVICES = "services"
+PLUGIN_SCOPE_COMMANDS = "commands"
 
 # maps from API names to list of other API names that they depend on
 API_DEPENDENCIES = {
-    'dynamodb': ['dynamodbstreams'],
-    'dynamodbstreams': ['kinesis'],
-    'es': ['elasticsearch'],
-    'lambda': ['logs', 'cloudwatch'],
-    'kinesis': ['dynamodb'],
-    'firehose': ['kinesis']
+    "dynamodb": ["dynamodbstreams"],
+    "dynamodbstreams": ["kinesis"],
+    "es": ["elasticsearch"],
+    "lambda": ["logs", "cloudwatch"],
+    "kinesis": ["dynamodb"],
+    "firehose": ["kinesis"],
 }
 # composites define an abstract name like "serverless" that maps to a set of services
 API_COMPOSITES = {
-    'serverless': ['cloudformation', 'cloudwatch', 'iam', 'sts', 'lambda', 'dynamodb', 'apigateway', 's3'],
-    'cognito': ['cognito-idp', 'cognito-identity']
+    "serverless": [
+        "cloudformation",
+        "cloudwatch",
+        "iam",
+        "sts",
+        "lambda",
+        "dynamodb",
+        "apigateway",
+        "s3",
+    ],
+    "cognito": ["cognito-idp", "cognito-identity"],
 }
 
 # main container name determined via "docker inspect"
@@ -64,12 +75,13 @@ MAIN_CONTAINER_NAME_CACHED = None
 
 # environment variable that indicates that we're executing in
 # the context of the script that starts the Docker container
-ENV_SCRIPT_STARTING_DOCKER = 'LS_SCRIPT_STARTING_DOCKER'
+ENV_SCRIPT_STARTING_DOCKER = "LS_SCRIPT_STARTING_DOCKER"
 
 
 def bootstrap_installation():
     try:
         from localstack.services import infra
+
         assert infra
     except Exception:
         install_dependencies()
@@ -77,65 +89,72 @@ def bootstrap_installation():
 
 def install_dependencies():
     # determine requirements
-    root_folder = os.path.join(os.path.dirname(os.path.realpath(__file__)), '..', '..')
-    reqs_file = os.path.join(root_folder, 'requirements.txt')
-    reqs_copy_file = os.path.join(root_folder, 'localstack', 'requirements.copy.txt')
+    root_folder = os.path.join(os.path.dirname(os.path.realpath(__file__)), "..", "..")
+    reqs_file = os.path.join(root_folder, "requirements.txt")
+    reqs_copy_file = os.path.join(root_folder, "localstack", "requirements.copy.txt")
     if not os.path.exists(reqs_copy_file):
         shutil.copy(reqs_file, reqs_copy_file)
     with open(reqs_copy_file) as f:
         requirements = f.read()
     install_requires = []
-    for line in re.split('\n', requirements):
-        if line and line[0] != '#':
+    for line in re.split("\n", requirements):
+        if line and line[0] != "#":
             if BASIC_LIB_MARKER not in line and IGNORED_LIB_MARKER not in line:
-                line = line.split(' #')[0].strip()
+                line = line.split(" #")[0].strip()
                 install_requires.append(line)
-    LOG.info('Lazily installing missing pip dependencies, this could take a while: %s' %
-             ', '.join(install_requires))
-    args = ['install'] + install_requires
+    LOG.info(
+        "Lazily installing missing pip dependencies, this could take a while: %s"
+        % ", ".join(install_requires)
+    )
+    args = ["install"] + install_requires
     return run_pip_main(args)
 
 
 def run_pip_main(args):
-    if hasattr(pip_mod, 'main'):
+    if hasattr(pip_mod, "main"):
         return pip_mod.main(args)
     import pip._internal
-    if hasattr(pip._internal, 'main'):
+
+    if hasattr(pip._internal, "main"):
         return pip._internal.main(args)
     import pip._internal.main
+
     return pip._internal.main.main(args)
 
 
 @log_duration()
 def load_plugin_from_path(file_path, scope=None):
     if os.path.exists(file_path):
-        delimiters = r'[\\/]'
-        not_delimiters = r'[^\\/]'
-        regex = r'(^|.+{d})({n}+){d}plugins.py'.format(d=delimiters, n=not_delimiters)
-        module = re.sub(regex, r'\2', file_path)
-        method_name = 'register_localstack_plugins'
+        delimiters = r"[\\/]"
+        not_delimiters = r"[^\\/]"
+        regex = r"(^|.+{d})({n}+){d}plugins.py".format(d=delimiters, n=not_delimiters)
+        module = re.sub(regex, r"\2", file_path)
+        method_name = "register_localstack_plugins"
         scope = scope or PLUGIN_SCOPE_SERVICES
         if scope == PLUGIN_SCOPE_COMMANDS:
-            method_name = 'register_localstack_commands'
+            method_name = "register_localstack_commands"
         try:
             namespace = {}
-            exec('from %s.plugins import %s' % (module, method_name), namespace)
+            exec("from %s.plugins import %s" % (module, method_name), namespace)
             method_to_execute = namespace[method_name]
         except Exception as e:
-            if (not re.match(r'.*cannot import name .*%s.*' % method_name, str(e)) and
-                    ('No module named' not in str(e))):
-                LOG.debug('Unable to load plugins from module %s: %s' % (module, e))
+            if not re.match(r".*cannot import name .*%s.*" % method_name, str(e)) and (
+                "No module named" not in str(e)
+            ):
+                LOG.debug("Unable to load plugins from module %s: %s" % (module, e))
             return
         try:
-            LOG.debug('Loading plugins - scope "%s", module "%s": %s' % (scope, module, method_to_execute))
+            LOG.debug(
+                'Loading plugins - scope "%s", module "%s": %s' % (scope, module, method_to_execute)
+            )
             return method_to_execute()
         except Exception as e:
             if not os.environ.get(ENV_SCRIPT_STARTING_DOCKER):
-                LOG.warning('Unable to load plugins from file %s: %s' % (file_path, e))
+                LOG.warning("Unable to load plugins from file %s: %s" % (file_path, e))
 
 
 def should_load_module(module, scope):
-    if module == 'localstack_ext' and not os.environ.get('LOCALSTACK_API_KEY'):
+    if module == "localstack_ext" and not os.environ.get("LOCALSTACK_API_KEY"):
         return False
     return True
 
@@ -147,7 +166,9 @@ def load_plugins(scope=None):
         return PLUGINS_LOADED[scope]
 
     t1 = now_utc()
-    is_infra_process = os.environ.get(constants.LOCALSTACK_INFRA_PROCESS) in ['1', 'true'] or '--host' in sys.argv
+    is_infra_process = (
+        os.environ.get(constants.LOCALSTACK_INFRA_PROCESS) in ["1", "true"] or "--host" in sys.argv
+    )
     log_level = logging.WARNING if scope == PLUGIN_SCOPE_COMMANDS and not is_infra_process else None
     setup_logging(log_level=log_level)
 
@@ -165,15 +186,15 @@ def load_plugins(scope=None):
         if isinstance(module, six.string_types):
             loader = pkgutil.get_loader(module)
             if loader:
-                path = getattr(loader, 'path', '') or getattr(loader, 'filename', '')
-                if '__init__.py' in path:
+                path = getattr(loader, "path", "") or getattr(loader, "filename", "")
+                if "__init__.py" in path:
                     path = os.path.dirname(path)
-                file_path = os.path.join(path, 'plugins.py')
+                file_path = os.path.join(path, "plugins.py")
         elif six.PY3 and not isinstance(module, tuple):
-            file_path = os.path.join(module.module_finder.path, module.name, 'plugins.py')
+            file_path = os.path.join(module.module_finder.path, module.name, "plugins.py")
         elif six.PY3 or isinstance(module[0], pkgutil.ImpImporter):
-            if hasattr(module[0], 'path'):
-                file_path = os.path.join(module[0].path, module[1], 'plugins.py')
+            if hasattr(module[0], "path"):
+                file_path = os.path.join(module[0].path, module[1], "plugins.py")
         if file_path and file_path not in loaded_files:
             plugin_config = load_plugin_from_path(file_path, scope=scope)
             if plugin_config:
@@ -185,7 +206,7 @@ def load_plugins(scope=None):
     # debug plugin loading time
     load_time = now_utc() - t1
     if load_time > 5:
-        LOG.debug('Plugin loading took %s sec' % load_time)
+        LOG.debug("Plugin loading took %s sec" % load_time)
 
     return result
 
@@ -198,7 +219,7 @@ def docker_container_running(container_name):
 def get_docker_image_details(image_name=None):
     image_name = image_name or get_docker_image_to_start()
     try:
-        result = run('%s inspect %s' % (config.DOCKER_CMD, image_name), print_error=False)
+        result = run("%s inspect %s" % (config.DOCKER_CMD, image_name), print_error=False)
         result = json.loads(to_str(result))
         assert len(result)
     except Exception:
@@ -207,9 +228,9 @@ def get_docker_image_details(image_name=None):
         LOG.warning('Found multiple images (%s) named "%s"' % (len(result), image_name))
     result = result[0]
     result = {
-        'id': result['Id'].replace('sha256:', '')[:12],
-        'tag': (result.get('RepoTags') or ['latest'])[0].split(':')[-1],
-        'created': result['Created'].split('.')[0]
+        "id": result["Id"].replace("sha256:", "")[:12],
+        "tag": (result.get("RepoTags") or ["latest"])[0].split(":")[-1],
+        "created": result["Created"].split(".")[0],
     }
     return result
 
@@ -218,7 +239,7 @@ def get_docker_container_names():
     cmd = "%s ps --format '{{.Names}}'" % config.DOCKER_CMD
     try:
         output = to_str(run(cmd))
-        container_names = re.split(r'\s+', output.strip().replace('\n', ' '))
+        container_names = re.split(r"\s+", output.strip().replace("\n", " "))
         return container_names
     except Exception as e:
         LOG.info('Unable to list Docker containers via "%s": %s' % (cmd, e))
@@ -227,8 +248,10 @@ def get_docker_container_names():
 
 def get_main_container_ip():
     container_name = get_main_container_name()
-    cmd = ("%s inspect -f '{{range .NetworkSettings.Networks}}{{.IPAddress}}{{end}}' %s" %
-        (config.DOCKER_CMD, container_name))
+    cmd = "%s inspect -f '{{range .NetworkSettings.Networks}}{{.IPAddress}}{{end}}' %s" % (
+        config.DOCKER_CMD,
+        container_name,
+    )
     return run(cmd, print_error=False).strip()
 
 
@@ -244,10 +267,10 @@ def get_main_container_id():
 def get_main_container_name():
     global MAIN_CONTAINER_NAME_CACHED
     if MAIN_CONTAINER_NAME_CACHED is None:
-        hostname = os.environ.get('HOSTNAME')
+        hostname = os.environ.get("HOSTNAME")
         cmd = "%s inspect -f '{{ .Name }}' %s" % (config.DOCKER_CMD, hostname)
         try:
-            MAIN_CONTAINER_NAME_CACHED = run(cmd, print_error=False).strip().lstrip('/')
+            MAIN_CONTAINER_NAME_CACHED = run(cmd, print_error=False).strip().lstrip("/")
         except Exception:
             MAIN_CONTAINER_NAME_CACHED = config.MAIN_CONTAINER_NAME
     return MAIN_CONTAINER_NAME_CACHED
@@ -258,15 +281,20 @@ def get_server_version():
     try:
         # try to extract from existing running container
         container_name = get_main_container_name()
-        version = run('%s exec -it %s bin/localstack --version' % (docker_cmd, container_name), print_error=False)
-        version = version.strip().split('\n')[-1]
+        version = run(
+            "%s exec -it %s bin/localstack --version" % (docker_cmd, container_name),
+            print_error=False,
+        )
+        version = version.strip().split("\n")[-1]
         return version
     except Exception:
         try:
             # try to extract by starting a new container
             img_name = get_docker_image_to_start()
-            version = run('%s run --entrypoint= -it %s bin/localstack --version' % (docker_cmd, img_name))
-            version = version.strip().split('\n')[-1]
+            version = run(
+                "%s run --entrypoint= -it %s bin/localstack --version" % (docker_cmd, img_name)
+            )
+            version = version.strip().split("\n")[-1]
             return version
         except Exception:
             # fall back to default constant
@@ -274,11 +302,11 @@ def get_server_version():
 
 
 def setup_logging(log_level=None):
-    """ Determine and set log level """
+    """Determine and set log level"""
 
-    if PLUGINS_LOADED.get('_logging_'):
+    if PLUGINS_LOADED.get("_logging_"):
         return
-    PLUGINS_LOADED['_logging_'] = True
+    PLUGINS_LOADED["_logging_"] = True
 
     # log level set by DEBUG env variable
     log_level = log_level or (logging.DEBUG if config.DEBUG else logging.INFO)
@@ -286,10 +314,12 @@ def setup_logging(log_level=None):
     # overriding the log level if LS_LOG has been set
     if config.LS_LOG:
         log_level = str(config.LS_LOG).upper()
-        log_level = 'WARNING' if log_level == 'WARN' else 'DEBUG' if log_level == 'TRACE' else log_level
+        log_level = (
+            "WARNING" if log_level == "WARN" else "DEBUG" if log_level == "TRACE" else log_level
+        )
         log_level = getattr(logging, log_level)
-        logging.getLogger('').setLevel(log_level)
-        logging.getLogger('localstack').setLevel(log_level)
+        logging.getLogger("").setLevel(log_level)
+        logging.getLogger("localstack").setLevel(log_level)
 
     logging.basicConfig(level=log_level, format=LOG_FORMAT, datefmt=LOG_DATE_FORMAT)
 
@@ -297,29 +327,29 @@ def setup_logging(log_level=None):
 
     class WerkzeugLogFilter(logging.Filter):
         def filter(self, record):
-            return record.name != 'werkzeug'
+            return record.name != "werkzeug"
 
     root_handlers = logging.getLogger().handlers
     if len(root_handlers) > 0:
         root_handlers[0].addFilter(WerkzeugLogFilter())
         if config.DEBUG:
-            format = '%(asctime)s:API: %(message)s'
+            format = "%(asctime)s:API: %(message)s"
             handler = logging.StreamHandler()
             handler.setLevel(logging.INFO)
             handler.setFormatter(logging.Formatter(format))
-            logging.getLogger('werkzeug').addHandler(handler)
+            logging.getLogger("werkzeug").addHandler(handler)
 
     # disable some logs and warnings
-    warnings.filterwarnings('ignore')
+    warnings.filterwarnings("ignore")
     logging.captureWarnings(True)
-    logging.getLogger('asyncio').setLevel(logging.INFO)
-    logging.getLogger('boto3').setLevel(logging.INFO)
-    logging.getLogger('s3transfer').setLevel(logging.INFO)
-    logging.getLogger('docker').setLevel(logging.WARNING)
-    logging.getLogger('urllib3').setLevel(logging.WARNING)
-    logging.getLogger('requests').setLevel(logging.WARNING)
-    logging.getLogger('botocore').setLevel(logging.ERROR)
-    logging.getLogger('elasticsearch').setLevel(logging.ERROR)
+    logging.getLogger("asyncio").setLevel(logging.INFO)
+    logging.getLogger("boto3").setLevel(logging.INFO)
+    logging.getLogger("s3transfer").setLevel(logging.INFO)
+    logging.getLogger("docker").setLevel(logging.WARNING)
+    logging.getLogger("urllib3").setLevel(logging.WARNING)
+    logging.getLogger("requests").setLevel(logging.WARNING)
+    logging.getLogger("botocore").setLevel(logging.ERROR)
+    logging.getLogger("elasticsearch").setLevel(logging.ERROR)
 
 
 # --------------
@@ -328,11 +358,11 @@ def setup_logging(log_level=None):
 
 
 def canonicalize_api_names(apis=None):
-    """ Finalize the list of API names by
-        (1) resolving and adding dependencies (e.g., "dynamodbstreams" requires "kinesis"),
-        (2) resolving and adding composites (e.g., "serverless" describes an ensemble
-                including "iam", "lambda", "dynamodb", "apigateway", "s3", "sns", and "logs"), and
-        (3) removing duplicates from the list. """
+    """Finalize the list of API names by
+    (1) resolving and adding dependencies (e.g., "dynamodbstreams" requires "kinesis"),
+    (2) resolving and adding composites (e.g., "serverless" describes an ensemble
+            including "iam", "lambda", "dynamodb", "apigateway", "s3", "sns", and "logs"), and
+    (3) removing duplicates from the list."""
 
     # TODO: cache the result, as the code below is a relatively expensive operation!
 
@@ -370,13 +400,14 @@ def canonicalize_api_names(apis=None):
 def is_api_enabled(api):
     apis = canonicalize_api_names()
     for a in apis:
-        if a == api or a.startswith('%s:' % api):
+        if a == api or a.startswith("%s:" % api):
             return True
 
 
 def start_infra_locally():
     bootstrap_installation()
     from localstack.services import infra
+
     return infra.start_infra()
 
 
@@ -392,75 +423,99 @@ def validate_localstack_config(name):
     try:
         run(cmd)
     except Exception as e:
-        LOG.warning('Looks like the docker-compose file is not valid: %s' % e)
+        LOG.warning("Looks like the docker-compose file is not valid: %s" % e)
         return False
 
     # validating docker-compose variable
     import yaml  # keep import here to avoid issues in test Lambdas
+
     with open(compose_file_name) as file:
         compose_content = yaml.full_load(file)
-    services_config = compose_content.get('services', {})
-    ls_service_name = [name for name, svc in services_config.items() if 'localstack' in svc.get('image', '')]
+    services_config = compose_content.get("services", {})
+    ls_service_name = [
+        name for name, svc in services_config.items() if "localstack" in svc.get("image", "")
+    ]
     if not ls_service_name:
-        raise Exception('No LocalStack service found in config (looking for image names containing "localstack")')
+        raise Exception(
+            'No LocalStack service found in config (looking for image names containing "localstack")'
+        )
     if len(ls_service_name) > 1:
-        LOG.warning('Multiple candidates found for LocalStack service: %s' % ls_service_name)
+        LOG.warning("Multiple candidates found for LocalStack service: %s" % ls_service_name)
     ls_service_name = ls_service_name[0]
     ls_service_details = services_config[ls_service_name]
-    image_name = ls_service_details.get('image', '')
-    if image_name.split(':')[0] not in constants.OFFICIAL_IMAGES:
-        LOG.info('Using custom image "%s", we recommend using an official image: %s' %
-            (image_name, constants.OFFICIAL_IMAGES))
+    image_name = ls_service_details.get("image", "")
+    if image_name.split(":")[0] not in constants.OFFICIAL_IMAGES:
+        LOG.info(
+            'Using custom image "%s", we recommend using an official image: %s'
+            % (image_name, constants.OFFICIAL_IMAGES)
+        )
 
     # prepare config options
-    network_mode = ls_service_details.get('network_mode')
-    image_name = ls_service_details.get('image')
-    container_name = ls_service_details.get('container_name') or ''
-    docker_ports = (port.split(':')[0] for port in ls_service_details.get('ports', []))
-    docker_env = dict((env.split('=')[0], env.split('=')[1])
-        for env in ls_service_details.get('environment', {}))
-    edge_port = str(docker_env.get('EDGE_PORT') or config.EDGE_PORT)
+    network_mode = ls_service_details.get("network_mode")
+    image_name = ls_service_details.get("image")
+    container_name = ls_service_details.get("container_name") or ""
+    docker_ports = (port.split(":")[0] for port in ls_service_details.get("ports", []))
+    docker_env = dict(
+        (env.split("=")[0], env.split("=")[1]) for env in ls_service_details.get("environment", {})
+    )
+    edge_port = str(docker_env.get("EDGE_PORT") or config.EDGE_PORT)
     main_container = config.MAIN_CONTAINER_NAME
 
     # docker-compose file validation cases
 
-    if docker_env.get('PORT_WEB_UI') not in ['${PORT_WEB_UI- }', None, ''] and image_name == 'localstack/localstack':
-        warns.append('"PORT_WEB_UI" Web UI is now deprecated, '
-                    'and requires to use the "localstack/localstack-full" image.')
+    if (
+        docker_env.get("PORT_WEB_UI") not in ["${PORT_WEB_UI- }", None, ""]
+        and image_name == "localstack/localstack"
+    ):
+        warns.append(
+            '"PORT_WEB_UI" Web UI is now deprecated, '
+            'and requires to use the "localstack/localstack-full" image.'
+        )
 
-    if not docker_env.get('HOST_TMP_FOLDER'):
-        warns.append('Please configure the "HOST_TMP_FOLDER" environment variable to point to the ' +
-            'absolute path of a temp folder on your host system (e.g., HOST_TMP_FOLDER=${TMPDIR})')
+    if not docker_env.get("HOST_TMP_FOLDER"):
+        warns.append(
+            'Please configure the "HOST_TMP_FOLDER" environment variable to point to the '
+            + "absolute path of a temp folder on your host system (e.g., HOST_TMP_FOLDER=${TMPDIR})"
+        )
 
-    if (main_container not in container_name) and not docker_env.get('MAIN_CONTAINER_NAME'):
-        warns.append('Please use "container_name: %s" or add "MAIN_CONTAINER_NAME" in "environment".' %
-            main_container)
+    if (main_container not in container_name) and not docker_env.get("MAIN_CONTAINER_NAME"):
+        warns.append(
+            'Please use "container_name: %s" or add "MAIN_CONTAINER_NAME" in "environment".'
+            % main_container
+        )
 
     def port_exposed(port):
         for exposed in docker_ports:
-            if re.match(r'^([0-9]+-)?%s(-[0-9]+)?$' % port, exposed):
+            if re.match(r"^([0-9]+-)?%s(-[0-9]+)?$" % port, exposed):
                 return True
 
     if not port_exposed(edge_port):
-        warns.append(('Edge port %s is not exposed. You may have to add the entry '
-                    'to the "ports" section of the docker-compose file.') % edge_port)
+        warns.append(
+            (
+                "Edge port %s is not exposed. You may have to add the entry "
+                'to the "ports" section of the docker-compose file.'
+            )
+            % edge_port
+        )
 
-    if network_mode != 'bridge' and not docker_env.get('LAMBDA_DOCKER_NETWORK'):
-        warns.append('Network mode is not set to "bridge" which may cause networking issues in Lambda containers. '
-                    'Consider adding "network_mode: bridge" to your docker-compose file, or configure '
-                    'LAMBDA_DOCKER_NETWORK with the name of the Docker network of your compose stack.')
+    if network_mode != "bridge" and not docker_env.get("LAMBDA_DOCKER_NETWORK"):
+        warns.append(
+            'Network mode is not set to "bridge" which may cause networking issues in Lambda containers. '
+            'Consider adding "network_mode: bridge" to your docker-compose file, or configure '
+            "LAMBDA_DOCKER_NETWORK with the name of the Docker network of your compose stack."
+        )
 
     # print warning/info messages
     for warning in warns:
         LOG.warning(warning)
     if not warnings:
-        LOG.info('Done validating config file %s - no issues found' % compose_file_name)
+        LOG.info("Done validating config file %s - no issues found" % compose_file_name)
         return True
     return False
 
 
 class PortMappings(object):
-    """ Maps source to target port ranges for Docker port mappings. """
+    """Maps source to target port ranges for Docker port mappings."""
 
     class HashableList(list):
         def __hash__(self):
@@ -469,7 +524,8 @@ class PortMappings(object):
                 result += hash(i)
             return result
 
-    def __init__(self):
+    def __init__(self, bind_host=None):
+        self.bind_host = bind_host if bind_host else ""
         self.mappings = {}
 
     def add(self, port, mapped=None):
@@ -479,7 +535,7 @@ class PortMappings(object):
                 self.add(port[0] + i, mapped[0] + i)
             return
         if port is None or int(port) <= 0:
-            raise Exception('Unable to add mapping for invalid port: %s' % port)
+            raise Exception("Unable to add mapping for invalid port: %s" % port)
         if self.contains(port):
             return
         for from_range, to_range in self.mappings.items():
@@ -493,12 +549,14 @@ class PortMappings(object):
         self.mappings[self.HashableList([port, port])] = [mapped, mapped]
 
     def to_str(self):
+        bind_address = f"{self.bind_host}:" if self.bind_host else ""
+
         def entry(k, v):
             if k[0] == k[1] and v[0] == v[1]:
-                return '-p %s:%s' % (k[0], v[0])
-            return '-p %s-%s:%s-%s' % (k[0], k[1], v[0], v[1])
+                return "-p %s%s:%s" % (bind_address, k[0], v[0])
+            return "-p %s%s-%s:%s-%s" % (bind_address, k[0], k[1], v[0], v[1])
 
-        return ' '.join([entry(k, v) for k, v in self.mappings.items()])
+        return " ".join([entry(k, v) for k, v in self.mappings.items()])
 
     def contains(self, port):
         for from_range, to_range in self.mappings.items():
@@ -519,21 +577,21 @@ class PortMappings(object):
         elif port == range[1] + 1:
             range[1] = port
         else:
-            raise Exception('Unable to add port %s to existing range %s' % (port, range))
+            raise Exception("Unable to add port %s to existing range %s" % (port, range))
 
 
 def get_docker_image_to_start():
-    image_name = os.environ.get('IMAGE_NAME')
+    image_name = os.environ.get("IMAGE_NAME")
     if not image_name:
         image_name = constants.DOCKER_IMAGE_NAME
-        if os.environ.get('USE_LIGHT_IMAGE') in constants.FALSE_STRINGS:
+        if os.environ.get("USE_LIGHT_IMAGE") in constants.FALSE_STRINGS:
             image_name = constants.DOCKER_IMAGE_NAME_FULL
     return image_name
 
 
 def extract_port_flags(user_flags, port_mappings):
-    regex = r'-p\s+([0-9]+)(\-([0-9]+))?:([0-9]+)(\-([0-9]+))?'
-    matches = re.match('.*%s' % regex, user_flags)
+    regex = r"-p\s+([0-9]+)(\-([0-9]+))?:([0-9]+)(\-([0-9]+))?"
+    matches = re.match(".*%s" % regex, user_flags)
     start = end = 0
     if matches:
         for match in re.findall(regex, user_flags):
@@ -542,7 +600,7 @@ def extract_port_flags(user_flags, port_mappings):
             start_target = int(match[3] or start)
             end_target = int(match[5] or end)
             port_mappings.add([start, end], [start_target, end_target])
-        user_flags = re.sub(regex, r'', user_flags)
+        user_flags = re.sub(regex, r"", user_flags)
     return user_flags
 
 
@@ -553,7 +611,7 @@ def start_infra_in_docker():
     if docker_container_running(container_name):
         raise Exception('LocalStack container named "%s" is already running' % container_name)
 
-    os.environ[ENV_SCRIPT_STARTING_DOCKER] = '1'
+    os.environ[ENV_SCRIPT_STARTING_DOCKER] = "1"
 
     # load plugins before starting the docker container
     plugin_configs = load_plugins()
@@ -561,50 +619,50 @@ def start_infra_in_docker():
     # prepare APIs
     canonicalize_api_names()
 
-    entrypoint = os.environ.get('ENTRYPOINT', '')
-    cmd = os.environ.get('CMD', '')
+    entrypoint = os.environ.get("ENTRYPOINT", "")
+    cmd = os.environ.get("CMD", "")
     user_flags = config.DOCKER_FLAGS
     image_name = get_docker_image_to_start()
     service_ports = config.SERVICE_PORTS
-    force_noninteractive = os.environ.get('FORCE_NONINTERACTIVE', '')
+    force_noninteractive = os.environ.get("FORCE_NONINTERACTIVE", "")
 
     # get run params
-    plugin_run_params = ' '.join([
-        entry.get('docker', {}).get('run_flags', '') for entry in plugin_configs])
+    plugin_run_params = " ".join(
+        [entry.get("docker", {}).get("run_flags", "") for entry in plugin_configs]
+    )
 
     # container for port mappings
-    port_mappings = PortMappings()
+    port_mappings = PortMappings(bind_host=config.EDGE_BIND_HOST)
 
     # get port ranges defined via DOCKER_FLAGS (if any)
     user_flags = extract_port_flags(user_flags, port_mappings)
     plugin_run_params = extract_port_flags(plugin_run_params, port_mappings)
 
     # construct default port mappings
-    if service_ports.get('edge') == 0:
-        service_ports.pop('edge')
-    service_ports.pop('dashboard', None)
+    if service_ports.get("edge") == 0:
+        service_ports.pop("edge")
     for port in service_ports.values():
         port_mappings.add(port)
 
-    env_str = ''
+    env_str = ""
     for env_var in config.CONFIG_ENV_VARS:
         value = os.environ.get(env_var, None)
         if value is not None:
             env_str += '-e %s="%s" ' % (env_var, value)
 
-    data_dir_mount = ''
-    data_dir = os.environ.get('DATA_DIR', None)
+    data_dir_mount = ""
+    data_dir = os.environ.get("DATA_DIR", None)
     if data_dir is not None:
-        container_data_dir = '/tmp/localstack_data'
+        container_data_dir = "/tmp/localstack_data"
         data_dir_mount = '-v "%s:%s"' % (data_dir, container_data_dir)
         env_str += '-e DATA_DIR="%s" ' % container_data_dir
 
-    interactive = '' if force_noninteractive or in_ci() else '-it '
+    interactive = "" if force_noninteractive or in_ci() else "-it "
 
     # append space if parameter is set
-    user_flags = '%s ' % user_flags if user_flags else user_flags
-    entrypoint = '%s ' % entrypoint if entrypoint else entrypoint
-    plugin_run_params = '%s ' % plugin_run_params if plugin_run_params else plugin_run_params
+    user_flags = "%s " % user_flags if user_flags else user_flags
+    entrypoint = "%s " % entrypoint if entrypoint else entrypoint
+    plugin_run_params = "%s " % plugin_run_params if plugin_run_params else plugin_run_params
     if config.START_WEB:
         for port in [config.PORT_WEB_UI, config.PORT_WEB_UI_SSL]:
             port_mappings.add(port)
@@ -612,17 +670,31 @@ def start_infra_in_docker():
     if config.DEVELOP:
         port_mappings.add(config.DEVELOP_PORT)
 
-    docker_cmd = ('%s run %s%s%s%s%s' +
-        '--rm --privileged ' +
-        '--name %s ' +
-        '%s %s ' +
-        '-v "%s:/tmp/localstack" -v "%s:%s" ' +
-        '-e DOCKER_HOST="unix://%s" ' +
-        '-e HOST_TMP_FOLDER="%s" "%s" %s') % (
-            config.DOCKER_CMD, interactive, entrypoint, env_str, user_flags, plugin_run_params,
-            container_name, port_mappings.to_str(), data_dir_mount,
-            config.TMP_FOLDER, config.DOCKER_SOCK, config.DOCKER_SOCK, config.DOCKER_SOCK,
-            config.HOST_TMP_FOLDER, image_name, cmd
+    docker_cmd = (
+        "%s run %s%s%s%s%s"
+        + "--rm --privileged "
+        + "--name %s "
+        + "%s %s "
+        + '-v "%s:/tmp/localstack" -v "%s:%s" '
+        + '-e DOCKER_HOST="unix://%s" '
+        + '-e HOST_TMP_FOLDER="%s" "%s" %s'
+    ) % (
+        config.DOCKER_CMD,
+        interactive,
+        entrypoint,
+        env_str,
+        user_flags,
+        plugin_run_params,
+        container_name,
+        port_mappings.to_str(),
+        data_dir_mount,
+        config.TMP_FOLDER,
+        config.DOCKER_SOCK,
+        config.DOCKER_SOCK,
+        config.DOCKER_SOCK,
+        config.HOST_TMP_FOLDER,
+        image_name,
+        cmd,
     )
 
     mkdir(config.TMP_FOLDER)
@@ -652,7 +724,10 @@ def start_infra_in_docker():
             if docker_container_running(container_name):
                 break
             time.sleep(2)
-        run('%s exec -u root "%s" chmod 777 /var/run/docker.sock' % (config.DOCKER_CMD, container_name))
+        run(
+            '%s exec -u root "%s" chmod 777 /var/run/docker.sock'
+            % (config.DOCKER_CMD, container_name)
+        )
 
     t.process.wait()
     sys.exit(t.process.returncode)
@@ -662,25 +737,26 @@ def start_infra_in_docker():
 # UTIL FUNCTIONS
 # ---------------
 
+
 def now_utc():
     epoch = datetime.utcfromtimestamp(0)
     return (datetime.utcnow() - epoch).total_seconds()
 
 
-def to_str(obj, errors='strict'):
-    return obj.decode('utf-8', errors) if isinstance(obj, six.binary_type) else obj
+def to_str(obj, errors="strict"):
+    return obj.decode("utf-8", errors) if isinstance(obj, six.binary_type) else obj
 
 
 def in_ci():
-    """ Whether or not we are running in a CI environment """
-    for key in ('CI', 'TRAVIS'):
-        if os.environ.get(key, '') not in [False, '', '0', 'false']:
+    """Whether or not we are running in a CI environment"""
+    for key in ("CI", "TRAVIS"):
+        if os.environ.get(key, "") not in [False, "", "0", "false"]:
             return True
     return False
 
 
 class FuncThread(threading.Thread):
-    """ Helper class to run a Python function in a background thread. """
+    """Helper class to run a Python function in a background thread."""
 
     def __init__(self, func, params=None, quiet=False):
         threading.Thread.__init__(self)
@@ -696,14 +772,16 @@ class FuncThread(threading.Thread):
         try:
             kwargs = {}
             argspec = inspect.getfullargspec(self.func)
-            if argspec.varkw or '_thread' in (argspec.args or []) + (argspec.kwonlyargs or []):
-                kwargs['_thread'] = self
+            if argspec.varkw or "_thread" in (argspec.args or []) + (argspec.kwonlyargs or []):
+                kwargs["_thread"] = self
             result = self.func(self.params, **kwargs)
         except Exception as e:
             result = e
             if not self.quiet:
-                LOG.warning('Thread run method %s(%s) failed: %s %s' %
-                    (self.func, self.params, e, traceback.format_exc()))
+                LOG.info(
+                    "Thread run method %s(%s) failed: %s %s"
+                    % (self.func, self.params, e, traceback.format_exc())
+                )
         finally:
             try:
                 self.result_future.set_result(result)
@@ -719,8 +797,18 @@ class FuncThread(threading.Thread):
         self._stop_event.set()
 
 
-def run(cmd, print_error=True, asynchronous=False, stdin=False, stderr=subprocess.STDOUT,
-        outfile=None, env_vars=None, inherit_cwd=False, inherit_env=True, tty=False):
+def run(
+    cmd,
+    print_error=True,
+    asynchronous=False,
+    stdin=False,
+    stderr=subprocess.STDOUT,
+    outfile=None,
+    env_vars=None,
+    inherit_cwd=False,
+    inherit_env=True,
+    tty=False,
+):
     env_dict = os.environ.copy() if inherit_env else {}
     if env_vars:
         env_dict.update(env_vars)
@@ -734,17 +822,24 @@ def run(cmd, print_error=True, asynchronous=False, stdin=False, stderr=subproces
         cwd = os.getcwd() if inherit_cwd else None
         if not asynchronous:
             if stdin:
-                return subprocess.check_output(cmd, shell=True, stderr=stderr, env=env_dict,
-                    stdin=subprocess.PIPE, cwd=cwd)
+                return subprocess.check_output(
+                    cmd,
+                    shell=True,
+                    stderr=stderr,
+                    env=env_dict,
+                    stdin=subprocess.PIPE,
+                    cwd=cwd,
+                )
             output = subprocess.check_output(cmd, shell=True, stderr=stderr, env=env_dict, cwd=cwd)
             return output.decode(config.DEFAULT_ENCODING)
 
         stdin_arg = subprocess.PIPE if stdin else None
-        stdout_arg = open(outfile, 'ab') if isinstance(outfile, six.string_types) else outfile
+        stdout_arg = open(outfile, "ab") if isinstance(outfile, six.string_types) else outfile
         stderr_arg = stderr
         if tty:
             # Note: leave the "pty" import here (not supported in Windows)
             import pty
+
             master_fd, slave_fd = pty.openpty()
             stdin_arg = slave_fd
             stdout_arg = stderr_arg = None
@@ -752,9 +847,18 @@ def run(cmd, print_error=True, asynchronous=False, stdin=False, stderr=subproces
         # start the actual sub process
         kwargs = {}
         if is_linux() or is_mac_os():
-            kwargs['preexec_fn'] = os.setsid
-        process = subprocess.Popen(cmd, shell=True, stdin=stdin_arg, bufsize=-1,
-            stderr=stderr_arg, stdout=stdout_arg, env=env_dict, cwd=cwd, **kwargs)
+            kwargs["preexec_fn"] = os.setsid
+        process = subprocess.Popen(
+            cmd,
+            shell=True,
+            stdin=stdin_arg,
+            bufsize=-1,
+            stderr=stderr_arg,
+            stdout=stdout_arg,
+            env=env_dict,
+            cwd=cwd,
+            **kwargs,
+        )
 
         if tty:
             # based on: https://stackoverflow.com/questions/41542960
@@ -780,18 +884,18 @@ def run(cmd, print_error=True, asynchronous=False, stdin=False, stderr=subproces
 
 
 def is_mac_os():
-    return 'Darwin' in get_uname()
+    return "Darwin" in get_uname()
 
 
 def is_linux():
-    return 'Linux' in get_uname()
+    return "Linux" in get_uname()
 
 
 def get_uname():
     try:
-        return to_str(subprocess.check_output('uname -a', shell=True))
+        return to_str(subprocess.check_output("uname -a", shell=True))
     except Exception:
-        return ''
+        return ""
 
 
 def mkdir(folder):
